"use client";

import { Box, Flex, HStack, Link as ChakraLink, Stack, VisuallyHidden, Spacer, Text, Button, Popover, PopoverTrigger, PopoverContent, PopoverArrow, PopoverCloseButton, PopoverBody, useStyleConfig, Grid } from "@chakra-ui/react";
import Link from "next/link";
import { useEffect, useMemo, useRef, useState } from "react";

import { useRouter } from "next/navigation";
import SearchComponent from "./search-nav";
import MobileSearchComponent from "./mobile/search";


export default function Header({ hasMobileNavigation = true, hasSearch = true, hasCTA = true, transparent = false, colorMode = "light" }: { colorMode?: String; hasMobileNavigation?: Boolean; hasSearch?: Boolean; hasCTA?: Boolean; transparent?: Boolean }) {
  // This need to check where its getting true or false
  // hasMobileNavigation;

  const container = useRef<HTMLDivElement>(null);
  const [mobileNavOpen, setMobileNavOpen] = useState(false);
  const [searchNavOpen, setSearchNavOpen] = useState(false);
  /** this hook manages state **/
  const [hidden, setHidden] = useState(false);
  /** this hook gets the scroll y-axis **/
  const [position, setPosition] = useState<string>("relative");
  const [sticky, setSticky] = useState(false);
  const router = useRouter();
  const [isCategoriesPopoverOpen, setCategoriesPopoverOpen] = useState(false);
  const handleOpenCategories = () => {
    setCategoriesPopoverOpen(true);
  };

  const handleCloseCategories = () => {
    setCategoriesPopoverOpen(false);
  };

  const handleFocusCategories = () => {
    // Set focus logic here if needed
  };

  /** add this const **/
  const variants = {
    /** this is the "visible" key and it's correlating styles **/
    visible: { opacity: 1, y: 0 },
    /** this is the "hidden" key and it's correlating styles **/
    hidden: { opacity: 0, y: -25 },
  };

  const navStyles = {
    display: "block",
    position: "fixed",
    alignItems: "center",
    justifyContent: "space-between",
    width: "100vw",
    left: "0",
    zIndex: 999,
  };

  useEffect(() => {
    const handleOutsideClick = (event: MouseEvent) => {
      if (!container?.current?.contains(event.target as Node)) {
        if (!mobileNavOpen) return;

        setMobileNavOpen(false);
        setSearchNavOpen(false);
      }
    };

    window.addEventListener("click", handleOutsideClick);

    return () => window.removeEventListener("click", handleOutsideClick);
  }, [mobileNavOpen, container]);

  useEffect(() => {
    const handleEscape = (event: KeyboardEvent) => {
      if (!mobileNavOpen) return;

      if (event.key === "Escape") {
        setMobileNavOpen(false);
        setSearchNavOpen(false);
      }
    };

    // Locks the scroll on body when the user is viewing the menu.
    if (mobileNavOpen) document.body.style.overflow = "hidden";
    if (!mobileNavOpen) document.body.style.overflow = "unset";

    document.addEventListener("keyup", handleEscape);

    return () => document.removeEventListener("keyup", handleEscape);
  }, [mobileNavOpen]);

  

  const navbarProps = useMemo(() => {
    var properties = {
      bgColor: colorMode == "light" ? "white" : "wildSand.100",
      boxShadow: "base",
      _hover: {
        bg: transparent && (colorMode == "light" ? "primary.100" : "wildSand.100"),
      },
    };
    if (transparent) {
      if (sticky) {
        properties.bgColor = colorMode == "light" ? "white" : "wildSand.100";
        properties.boxShadow = "base";
      } else {
        if (searchNavOpen) {
          properties.bgColor = colorMode == "dark" ? "wildSand.100":"";
        } else {
          properties.bgColor = "transparent";
        }
        properties.boxShadow = "none";
      }
    }

    return {
      bg: properties.bgColor,
      boxShadow: properties.boxShadow,
    };
  }, [sticky, transparent, colorMode, searchNavOpen]);

 

  useEffect(() => {
    const handleResize = () => {
      const isMobile = window.innerWidth <= 768; // Adjust the breakpoint as needed
      // if (!isMobile) {
      //   setSearchDrawerOpen(false);
      // }
    };

    window.addEventListener("resize", handleResize);
    handleResize(); // Initial check on mount

    return () => {
      window.removeEventListener("resize", handleResize);
    };
  }, []);

  // Define a custom style configuration for the popover
  const popoverStyle = useStyleConfig("Popover", { variant: "custom" });

  const CTASection: React.FC<CTASectionProps> = ({ buttonProps }) => {
      
    const props = {
      size: "md",
      px: "6",
      ...buttonProps,
    };
    return (
      <Box display="flex" gap={4}>
        <Button key={"signup"} colorScheme="primary" variant="ghost" {...props}>
          Login
        </Button>
        <Button key={"login"} colorScheme="primary"  variant="solid" {...props}>
          Sign up
        </Button>
      </Box>
    );
  };


  return (
    <Box position="relative">
      <Box ref={container} visibility={hidden ? "hidden" : "visible"} pos={"relative"} sx={{navStyles}} {...navbarProps}>
        <Box maxW="7xl" mx="auto" px={[4, 6]}>
          <Stack display="flex" justifyContent={["space-between", null, "flex-start"]} alignItems="center" py={6} direction="row" spacing={{ md: 10 }}>
            <Flex w={{ lg: "1 1 0" }} flex={{ md: "1 1 0" }}>
              <Link href="/">
                <VisuallyHidden>ZinTool</VisuallyHidden>
                <Text color={"primary.500"} fontSize={"lg"} fontWeight={"bold"}>
                  Logo Here
                </Text>
              </Link>
              <Spacer />
              <SearchComponent></SearchComponent>
              <Spacer />
            </Flex>
            <HStack display={{ base: "flex", md: "none" }}>
              <MobileSearchComponent />
            </HStack>

            <Stack as="nav" display={["none", null, "flex"]} direction="row" spacing={5} role="menu" alignItems="center">
              <HStack>
                <CTASection />
              </HStack>
            </Stack>
          </Stack>
          <Stack display="Flex">
            <Box display={{ base: "none", md: "block" }}>
              <Flex align="center" gap={6}>
                <ChakraLink
                  as={Link}
                  href="#"
                  px={4}
                  color="codGray.500"
                  variant={"solid"}
                  sx={{
                    // Apply custom styles using Chakra's sx prop
                    _hover: {
                      // Apply styles on hover
                      borderBottomColor: "blue.500",
                      borderBottomWidth: "2px",
                      py: 2,
                      bg: "transparent",
                    },
                  }}>
                  Home
                </ChakraLink>

                <Popover trigger="hover" isOpen={isCategoriesPopoverOpen} onOpen={handleOpenCategories} onClose={handleCloseCategories}>
                  <PopoverTrigger>
                    <Button
                      bg="transparent"
                      borderRadius="none"
                      color="codGray.500"
                      fontWeight="0"
                      onClick={handleFocusCategories}
                      sx={{
                        _hover: {
                          // Apply styles on hover
                          borderBottomColor: "blue.500",
                          borderBottomWidth: "2px",
                        },
                      }}>
                      Categories
                    </Button>
                  </PopoverTrigger>
                  <PopoverContent>
                    <PopoverArrow />
                    <PopoverCloseButton />
                    <PopoverBody>
                      <Grid py={1} templateColumns={{ base: `repeat(1, 1fr)` }} gap={4}>
                        <ChakraLink as={Link} color={"primary.500"} href="#">
                          Category 1
                        </ChakraLink>
                        <ChakraLink as={Link} color={"primary.500"} href="#">
                          Category 2
                        </ChakraLink>
                      </Grid>
                      {/* Add more categories as needed */}
                    </PopoverBody>
                  </PopoverContent>
                </Popover>

                <ChakraLink
                  as={Link}
                  px={4}
                  color="codGray.500"
                  variant={"solid"}
                  sx={{
                    // Apply custom styles using Chakra's sx prop
                    _hover: {
                      // Apply styles on hover
                      borderBottomColor: "blue.500",
                      borderBottomWidth: "2px",
                      py: 2,
                      bg: "transparent",
                    },
                  }}
                  href="#">
                  Pricing
                </ChakraLink>
                <ChakraLink
                  as={Link}
                  px={4}
                  color="codGray.500"
                  variant={"solid"}
                  sx={{
                    // Apply custom styles using Chakra's sx prop
                    _hover: {
                      // Apply styles on hover
                      borderBottomColor: "blue.500",
                      borderBottomWidth: "2px",
                      py: 2,
                      bg: "transparent",
                    },
                  }}
                  href="#">
                  Contact
                </ChakraLink>
              </Flex>
            </Box>
          </Stack>
        </Box>
      </Box>
      <Box height="88px"></Box> {/** Box to produce height. */}
    </Box>
  );
}

interface ButtonProps {
  size?: "sm" | "md" | "lg"; // Define the possible sizes
  // Add any other properties you expect for buttonProps
}

interface CTASectionProps {
  buttonProps?: ButtonProps;
}
